@@ -3,7 +3,9 @@ import pprint
 import pytest
 import os 
 
-apiaudio.api_key = os.getenv("AFLR_API_KEY_PEADAR")
+apiaudio.api_key = os.environ["AFLR_API_KEY"]
+apiaudio.api_base="https://staging-v1.api.audio"
+'''
 def test_english_voices():
     print("List test:\nAll voices:")
     print(len(apiaudio.Voice.list().get("voices")))
@@ -15,25 +17,20 @@ def test_spanish_voices():
 
 def test_list_parameters():
     assert len(apiaudio.Voice.list_parameters()) > 0 
-
+'''
 def test_sound_design():
-    sounds = apiaudio.Sound.list_sound_templates()
-    city_nights=sounds.get("templateFiles").get("citynights")
-    # Still not sure how to get this to work properly
-    assert len(city_nights) > 0
-    assert list(city_nights[1]) == ['citynights__music.wav']
+    sounds = apiaudio.Sound.list()
+    print(sounds)
 
 def test_create_scripts():
-    create_script= apiaudio.Script.create(scriptText="<<sectionName::question>> Hey! Do you know we support multiple voices from different providers in the same script? I am a polly voice from Amazon. <<sectionName::answer>> I am Azure voice from Microsoft. I think Azure voices sound awesome.")
-    scriptId = create_script.get("scriptId")
-    create_speech = apiaudio.Speech.create(scriptId=scriptId)
-    create_tts = {'message': 'Success. Text-to-speech is in progress.'}
-    assert create_speech == create_tts
+    create_script= apiaudio.Script.create(scriptId="test", scriptText="<<sectionName::question>> Hey! Do you know we support multiple voices from different providers in the same script? I am a polly voice from Amazon. <<sectionName::answer>> I am Azure voice from Microsoft. I think Azure voices sound awesome.")
+    get_script = apiaudio.Script.retrieve(scriptId="test")
+    apiaudio.Speech.create(scriptId="test", voice="brandon")
 
 def test_create_mastering():
     create_script= apiaudio.Script.create(scriptText="<<sectionName::question>> Hey! Do you know we support multiple voices from different providers in the same script? I am a polly voice from Amazon. <<sectionName::answer>> I am Azure voice from Microsoft. I think Azure voices sound awesome.")
     scriptId = create_script.get("scriptId")
-    apiaudio.Speech.create(scriptId=scriptId)
+    apiaudio.Speech.create(scriptId=scriptId, voice="brandon")
     mastering = apiaudio.Mastering.create(scriptId=scriptId)
     create_mastering = {'Message': 'Mastering request was successful'}
     assert len(mastering) > 0
@@ -50,3 +47,11 @@ def test_birdcache():
     assert len(birdcache) > 0
     assert birdcache[1]["text"] == "This is salih creating synchronous text to speech"
 
+def test_warnings(capfd):
+    mastering = apiaudio.Mastering.create(
+        scriptId="test",
+        forceLength=30000
+    )
+    out, err = capfd.readouterr()
+    assert out == "Hello World!"
+
